from fastmcp import Context
from typing_extensions import Annotated
from pydantic import Field
from files_com_mcp.utils import object_list_to_markdown_table
import files_sdk
import files_sdk.error


async def list_bundle_download(
    context: Context,
    bundle_id: Annotated[
        int | None, Field(description="Bundle ID", default=None)
    ],
) -> str:
    """List Bundle (also called Share Link) Downloads

    Args:
        bundle_id: Bundle ID
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if bundle_id is not None:
            params["bundle_id"] = bundle_id

        retval = files_sdk.bundle_download.list(params, options)
        retval = [item for item in retval.auto_paging_iter()]
        if not retval:
            return "No bundledownloads found."

        markdown_list = object_list_to_markdown_table(retval, ["bundle_id"])
        return f"BundleDownload Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


def register_tools(mcp):
    @mcp.tool(
        name="List_Bundle_Download",
        description="List Bundle (also called Share Link) Downloads",
    )
    async def list_bundle_download_tool(
        context: Context,
        bundle_id: Annotated[
            int | None, Field(description="Bundle ID", default=None)
        ],
    ) -> str:
        return await list_bundle_download(context, bundle_id)



from fastmcp import Context
from typing_extensions import Annotated
from pydantic import Field
from files_com_mcp.utils import object_list_to_markdown_table
import files_sdk
import files_sdk.error


async def list_group(context: Context) -> str:
    """List Groups"""

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}

        retval = files_sdk.group.list(params, options)
        retval = [item for item in retval.auto_paging_iter()]
        if not retval:
            return "No groups found."

        markdown_list = object_list_to_markdown_table(
            retval, ["id", "name", "notes", "user_ids", "admin_ids"]
        )
        return f"Group Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def find_group(
    context: Context,
    id: Annotated[int | None, Field(description="Group ID.", default=None)],
) -> str:
    """Show Group

    Args:
        id: Group ID.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if id is None:
            return "Missing required parameter: id"
        params["id"] = id

        retval = files_sdk.group.find(id, params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval, ["id", "name", "notes", "user_ids", "admin_ids"]
        )
        return f"Group Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def create_group(
    context: Context,
    name: Annotated[
        str | None, Field(description="Group name.", default=None)
    ],
    notes: Annotated[
        str | None, Field(description="Group notes.", default=None)
    ],
    user_ids: Annotated[
        str | None,
        Field(
            description="A list of user ids. If sent as a string, should be comma-delimited.",
            default=None,
        ),
    ],
    admin_ids: Annotated[
        str | None,
        Field(
            description="A list of group admin user ids. If sent as a string, should be comma-delimited.",
            default=None,
        ),
    ],
) -> str:
    """Create Group

    Args:
        name: Group name.
        notes: Group notes.
        user_ids: A list of user ids. If sent as a string, should be comma-delimited.
        admin_ids: A list of group admin user ids. If sent as a string, should be comma-delimited.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if name is None:
            return "Missing required parameter: name"
        params["name"] = name
        if notes is not None:
            params["notes"] = notes
        if user_ids is not None:
            params["user_ids"] = user_ids
        if admin_ids is not None:
            params["admin_ids"] = admin_ids

        retval = files_sdk.group.create(params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval, ["id", "name", "notes", "user_ids", "admin_ids"]
        )
        return f"Group Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def update_group(
    context: Context,
    id: Annotated[int | None, Field(description="Group ID.", default=None)],
    notes: Annotated[
        str | None, Field(description="Group notes.", default=None)
    ],
    user_ids: Annotated[
        str | None,
        Field(
            description="A list of user ids. If sent as a string, should be comma-delimited.",
            default=None,
        ),
    ],
    admin_ids: Annotated[
        str | None,
        Field(
            description="A list of group admin user ids. If sent as a string, should be comma-delimited.",
            default=None,
        ),
    ],
    name: Annotated[
        str | None, Field(description="Group name.", default=None)
    ],
) -> str:
    """Update Group

    Args:
        id: Group ID.
        notes: Group notes.
        user_ids: A list of user ids. If sent as a string, should be comma-delimited.
        admin_ids: A list of group admin user ids. If sent as a string, should be comma-delimited.
        name: Group name.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if id is None:
            return "Missing required parameter: id"
        params["id"] = id
        if notes is not None:
            params["notes"] = notes
        if user_ids is not None:
            params["user_ids"] = user_ids
        if admin_ids is not None:
            params["admin_ids"] = admin_ids
        if name is not None:
            params["name"] = name

        retval = files_sdk.group.update(id, params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval, ["id", "name", "notes", "user_ids", "admin_ids"]
        )
        return f"Group Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def delete_group(
    context: Context,
    id: Annotated[int | None, Field(description="Group ID.", default=None)],
) -> str:
    """Delete Group

    Args:
        id: Group ID.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if id is None:
            return "Missing required parameter: id"
        params["id"] = id

        retval = files_sdk.group.delete(id, params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval, ["id", "name", "notes", "user_ids", "admin_ids"]
        )
        return f"Group Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


def register_tools(mcp):
    @mcp.tool(name="List_Group", description="List Groups")
    async def list_group_tool(context: Context) -> str:
        return await list_group(context)

    @mcp.tool(name="Find_Group", description="Show Group")
    async def find_group_tool(
        context: Context,
        id: Annotated[
            int | None, Field(description="Group ID.", default=None)
        ],
    ) -> str:
        return await find_group(context, id)

    @mcp.tool(name="Create_Group", description="Create Group")
    async def create_group_tool(
        context: Context,
        name: Annotated[
            str | None, Field(description="Group name.", default=None)
        ],
        notes: Annotated[
            str | None, Field(description="Group notes.", default=None)
        ],
        user_ids: Annotated[
            str | None,
            Field(
                description="A list of user ids. If sent as a string, should be comma-delimited.",
                default=None,
            ),
        ],
        admin_ids: Annotated[
            str | None,
            Field(
                description="A list of group admin user ids. If sent as a string, should be comma-delimited.",
                default=None,
            ),
        ],
    ) -> str:
        return await create_group(context, name, notes, user_ids, admin_ids)

    @mcp.tool(name="Update_Group", description="Update Group")
    async def update_group_tool(
        context: Context,
        id: Annotated[
            int | None, Field(description="Group ID.", default=None)
        ],
        notes: Annotated[
            str | None, Field(description="Group notes.", default=None)
        ],
        user_ids: Annotated[
            str | None,
            Field(
                description="A list of user ids. If sent as a string, should be comma-delimited.",
                default=None,
            ),
        ],
        admin_ids: Annotated[
            str | None,
            Field(
                description="A list of group admin user ids. If sent as a string, should be comma-delimited.",
                default=None,
            ),
        ],
        name: Annotated[
            str | None, Field(description="Group name.", default=None)
        ],
    ) -> str:
        return await update_group(
            context, id, notes, user_ids, admin_ids, name
        )

    @mcp.tool(name="Delete_Group", description="Delete Group")
    async def delete_group_tool(
        context: Context,
        id: Annotated[
            int | None, Field(description="Group ID.", default=None)
        ],
    ) -> str:
        return await delete_group(context, id)



from mcp.server.session import ServerSession
import os

_original_init = ServerSession.__init__


def patched_init(self, *args, **kwargs):
    _original_init(self, *args, **kwargs)

    # Inject your custom attributes
    self._files_com_api_key = os.getenv("FILES_COM_API_KEY", "").strip()


ServerSession.__init__ = patched_init



tool_list = [
    "bundle",
    "bundle_download",
    "bundle_notification",
    "bundle_recipient",
    "bundle_registration",
    "file",
    "folder",
    "group",
    "user",
    "automation",
    "history",
    "permission",
    "remote_server",
]



import unittest
import logging
import json

import files_com_mcp
import files_sdk

class TestPathUtil(unittest.TestCase):
    @classmethod
    def setUpClass(cls):
        # Suppress logging to stdout/stderr, we will see errors at the end
        logging.getLogger("files_sdk").addHandler(logging.NullHandler())
        logging.getLogger("files_sdk").propagate = False

    def test_normalization_for_comparison(self):
        file1 = files_sdk.File("path1")
        file1.size = 12345 # type: ignore[attr-defined]
        file2 = files_sdk.File("path2")
        file2.size = 67890 # type: ignore[attr-defined]

        table = files_com_mcp.utils.object_list_to_markdown_table([file1, file2], ["path"])
        expected_table = "| path |\n| --- |\n| path1 |\n| path2 |"
        self.assertEqual(table, expected_table)

if __name__ == '__main__':
    unittest.main()




from fastmcp import Context
from typing_extensions import Annotated
from pydantic import Field
from files_com_mcp.utils import object_list_to_markdown_table
import files_sdk
import files_sdk.error


async def list_bundle_recipient(
    context: Context,
    bundle_id: Annotated[
        int | None,
        Field(
            description="List recipients for the bundle with this ID.",
            default=None,
        ),
    ],
) -> str:
    """List Bundle (also called Share Link) Recipients

    Args:
        bundle_id: List recipients for the bundle with this ID.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if bundle_id is None:
            return "Missing required parameter: bundle_id"
        params["bundle_id"] = bundle_id

        retval = files_sdk.bundle_recipient.list(params, options)
        retval = [item for item in retval.auto_paging_iter()]
        if not retval:
            return "No bundlerecipients found."

        markdown_list = object_list_to_markdown_table(
            retval, ["bundle_id", "recipient", "name", "company", "note"]
        )
        return f"BundleRecipient Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def create_bundle_recipient(
    context: Context,
    bundle_id: Annotated[
        int | None, Field(description="Bundle to share.", default=None)
    ],
    recipient: Annotated[
        str | None,
        Field(
            description="Email addresses to share this bundle with.",
            default=None,
        ),
    ],
    name: Annotated[
        str | None, Field(description="Name of recipient.", default=None)
    ],
    company: Annotated[
        str | None, Field(description="Company of recipient.", default=None)
    ],
    note: Annotated[
        str | None,
        Field(description="Note to include in email.", default=None),
    ],
) -> str:
    """Create Bundle (also called Share Link) Recipient

    Args:
        bundle_id: Bundle to share.
        recipient: Email addresses to share this bundle with.
        name: Name of recipient.
        company: Company of recipient.
        note: Note to include in email.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if bundle_id is None:
            return "Missing required parameter: bundle_id"
        params["bundle_id"] = bundle_id
        if recipient is None:
            return "Missing required parameter: recipient"
        params["recipient"] = recipient
        if name is not None:
            params["name"] = name
        if company is not None:
            params["company"] = company
        if note is not None:
            params["note"] = note

        # Smart Default(s)
        params["share_after_create"] = True

        retval = files_sdk.bundle_recipient.create(params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval, ["bundle_id", "recipient", "name", "company", "note"]
        )
        return f"BundleRecipient Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


def register_tools(mcp):
    @mcp.tool(
        name="List_Bundle_Recipient",
        description="List Bundle (also called Share Link) Recipients",
    )
    async def list_bundle_recipient_tool(
        context: Context,
        bundle_id: Annotated[
            int | None,
            Field(
                description="List recipients for the bundle with this ID.",
                default=None,
            ),
        ],
    ) -> str:
        return await list_bundle_recipient(context, bundle_id)

    @mcp.tool(
        name="Create_Bundle_Recipient",
        description="Create Bundle (also called Share Link) Recipient",
    )
    async def create_bundle_recipient_tool(
        context: Context,
        bundle_id: Annotated[
            int | None, Field(description="Bundle to share.", default=None)
        ],
        recipient: Annotated[
            str | None,
            Field(
                description="Email addresses to share this bundle with.",
                default=None,
            ),
        ],
        name: Annotated[
            str | None, Field(description="Name of recipient.", default=None)
        ],
        company: Annotated[
            str | None,
            Field(description="Company of recipient.", default=None),
        ],
        note: Annotated[
            str | None,
            Field(description="Note to include in email.", default=None),
        ],
    ) -> str:
        return await create_bundle_recipient(
            context, bundle_id, recipient, name, company, note
        )



import os
from fastmcp import Context
from typing_extensions import Annotated
from pydantic import Field
import files_sdk
import files_sdk.error


async def download_file_to_local(
    context: Context, remote_path: str, local_path: str
) -> str:
    """Download a file from my Files.com site. Specify the remote path of the file to download and a local path to save the file at.

    Args:
        remote_path: The full path on my Files.com site of the file to be downloaded.
        local_path: The full path on my local system to save the downloaded file to. Must be a path that can be written to. When in doubt, use the `$HOME/Downloads` folder, or the `/tmp/` folder, as the destination for the downloaded file.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }

        files_sdk.file.download_file(remote_path, local_path, options)
        return (
            f"File downloaded successfully to: {os.path.abspath(local_path)}"
        )

    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def upload_file_from_local(
    context: Context, local_path: str, remote_path: str
) -> str:
    """Upload a file to my Files.com site. Specify the local path of the file to upload and a remote path to save the file at.

    Args:
        local_path: The full path on my local system of the file to be uploaded.
        remote_path: The full path on my Files.com site for the file to be uploaded to.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}

        # Smart Default(s)
        params["mkdir_parents"] = True

        files_sdk.file.upload_file(local_path, remote_path, options, params)
        return (
            f"File uploaded successfully from: {os.path.abspath(local_path)}"
        )

    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


def register_tools(mcp):
    @mcp.tool(
        name="Download_File_to_Local",
        description="Download a file from my Files.com site.",
    )
    async def download_file_to_local_tool(
        context: Context,
        remote_path: Annotated[
            str,
            Field(
                description="The full path on my Files.com site of the file to be downloaded."
            ),
        ],
        local_path: Annotated[
            str,
            Field(
                description="The full path on my local system to save the downloaded file to. Must be a path that can be written to. When in doubt, use the `$HOME/Downloads` folder, or the `/tmp/` folder, as the destination for the downloaded file."
            ),
        ],
    ) -> str:
        return await download_file_to_local(context, remote_path, local_path)

    @mcp.tool(
        name="Upload_File_from_Local",
        description="Upload a file to my Files.com site.",
    )
    async def upload_file_from_local_tool(
        context: Context,
        local_path: Annotated[
            str,
            Field(
                description="The full path on my local system of the file to be uploaded."
            ),
        ],
        remote_path: Annotated[
            str,
            Field(
                description="The full path on my Files.com site for the file to be uploaded to."
            ),
        ],
    ) -> str:
        return await upload_file_from_local(context, local_path, remote_path)



import argparse
import os
import files_sdk
from files_com_mcp.server import run_stdio, run_server


def main():
    # For pointing to mock server for testing
    if os.getenv("FILES_COM_BASE_URL"):
        files_sdk.base_url = os.getenv("FILES_COM_BASE_URL")

    parser = argparse.ArgumentParser(description="Run MCP server")

    parser.add_argument(
        "--mode",
        choices=["stdio", "server"],
        default="stdio",
        help="Transport mode: stdio or server (HTTP)",
    )

    parser.add_argument(
        "--port", type=int, default=8000, help="Port to use in server mode"
    )

    args = parser.parse_args()

    if args.mode == "stdio":
        run_stdio()
    elif args.mode == "server":
        run_server(port=args.port)


if __name__ == "__main__":
    main()



from fastmcp import Context
from typing_extensions import Annotated
from pydantic import Field
from files_com_mcp.utils import object_list_to_markdown_table
import files_sdk
import files_sdk.error


async def list_for_file_history(
    context: Context,
    path: Annotated[
        str | None, Field(description="Path to operate on.", default=None)
    ],
) -> str:
    """List history for specific file.

    Args:
        path: Path to operate on.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if path is None:
            return "Missing required parameter: path"
        params["path"] = path

        retval = files_sdk.history.list_for_file(path, params, options)
        retval = [item for item in retval.auto_paging_iter()]
        if not retval:
            return "No histories found."

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "path",
                "when",
                "destination",
                "display",
                "ip",
                "source",
                "targets",
                "user_id",
                "username",
                "action",
                "failure_type",
                "interface",
            ],
        )
        return f"History Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def list_for_folder_history(
    context: Context,
    path: Annotated[
        str | None, Field(description="Path to operate on.", default=None)
    ],
) -> str:
    """List history for specific folder.

    Args:
        path: Path to operate on.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if path is None:
            return "Missing required parameter: path"
        params["path"] = path

        retval = files_sdk.history.list_for_folder(path, params, options)
        retval = [item for item in retval.auto_paging_iter()]
        if not retval:
            return "No histories found."

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "path",
                "when",
                "destination",
                "display",
                "ip",
                "source",
                "targets",
                "user_id",
                "username",
                "action",
                "failure_type",
                "interface",
            ],
        )
        return f"History Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def list_for_user_history(
    context: Context,
    user_id: Annotated[
        int | None, Field(description="User ID.", default=None)
    ],
) -> str:
    """List history for specific user.

    Args:
        user_id: User ID.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if user_id is None:
            return "Missing required parameter: user_id"
        params["user_id"] = user_id

        retval = files_sdk.history.list_for_user(user_id, params, options)
        retval = [item for item in retval.auto_paging_iter()]
        if not retval:
            return "No histories found."

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "path",
                "when",
                "destination",
                "display",
                "ip",
                "source",
                "targets",
                "user_id",
                "username",
                "action",
                "failure_type",
                "interface",
            ],
        )
        return f"History Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def list_logins_history(context: Context) -> str:
    """List site login history."""

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}

        retval = files_sdk.history.list_logins(params, options)
        retval = [item for item in retval.auto_paging_iter()]
        if not retval:
            return "No histories found."

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "path",
                "when",
                "destination",
                "display",
                "ip",
                "source",
                "targets",
                "user_id",
                "username",
                "action",
                "failure_type",
                "interface",
            ],
        )
        return f"History Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def list_history(context: Context) -> str:
    """List site full action history."""

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}

        retval = files_sdk.history.list(params, options)
        retval = [item for item in retval.auto_paging_iter()]
        if not retval:
            return "No histories found."

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "path",
                "when",
                "destination",
                "display",
                "ip",
                "source",
                "targets",
                "user_id",
                "username",
                "action",
                "failure_type",
                "interface",
            ],
        )
        return f"History Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


def register_tools(mcp):
    @mcp.tool(
        name="List_For_File_History",
        description="List history for specific file.",
    )
    async def list_for_file_history_tool(
        context: Context,
        path: Annotated[
            str | None, Field(description="Path to operate on.", default=None)
        ],
    ) -> str:
        return await list_for_file_history(context, path)

    @mcp.tool(
        name="List_For_Folder_History",
        description="List history for specific folder.",
    )
    async def list_for_folder_history_tool(
        context: Context,
        path: Annotated[
            str | None, Field(description="Path to operate on.", default=None)
        ],
    ) -> str:
        return await list_for_folder_history(context, path)

    @mcp.tool(
        name="List_For_User_History",
        description="List history for specific user.",
    )
    async def list_for_user_history_tool(
        context: Context,
        user_id: Annotated[
            int | None, Field(description="User ID.", default=None)
        ],
    ) -> str:
        return await list_for_user_history(context, user_id)

    @mcp.tool(
        name="List_Logins_History", description="List site login history."
    )
    async def list_logins_history_tool(context: Context) -> str:
        return await list_logins_history(context)

    @mcp.tool(
        name="List_History", description="List site full action history."
    )
    async def list_history_tool(context: Context) -> str:
        return await list_history(context)



from fastmcp import Context
from typing_extensions import Annotated
from pydantic import Field
from files_com_mcp.utils import object_list_to_markdown_table
import files_sdk
import files_sdk.error


async def list_for_folder(
    context: Context,
    path: Annotated[
        str | None, Field(description="Path to operate on.", default=None)
    ],
) -> str:
    """List Folders by Path

    Args:
        path: Path to operate on.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if path is None:
            return "Missing required parameter: path"
        params["path"] = path

        retval = files_sdk.folder.list_for(path, params, options)
        retval = [item for item in retval.auto_paging_iter()]
        if not retval:
            return "No folders found."

        markdown_list = object_list_to_markdown_table(retval, ["path"])
        return f"Folder Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def create_folder(
    context: Context,
    path: Annotated[
        str | None, Field(description="Path to operate on.", default=None)
    ],
) -> str:
    """Create Folder

    Args:
        path: Path to operate on.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if path is None:
            return "Missing required parameter: path"
        params["path"] = path

        # Smart Default(s)
        params["mkdir_parents"] = True

        retval = files_sdk.folder.create(path, params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(retval, ["path"])
        return f"Folder Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


def register_tools(mcp):
    @mcp.tool(name="List_For_Folder", description="List Folders by Path")
    async def list_for_folder_tool(
        context: Context,
        path: Annotated[
            str | None, Field(description="Path to operate on.", default=None)
        ],
    ) -> str:
        return await list_for_folder(context, path)

    @mcp.tool(name="Create_Folder", description="Create Folder")
    async def create_folder_tool(
        context: Context,
        path: Annotated[
            str | None, Field(description="Path to operate on.", default=None)
        ],
    ) -> str:
        return await create_folder(context, path)



from fastmcp import Context
from typing_extensions import Annotated
from pydantic import Field
from files_com_mcp.utils import object_list_to_markdown_table
import files_sdk
import files_sdk.error


async def list_remote_server(context: Context) -> str:
    """List Remote Servers"""

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}

        retval = files_sdk.remote_server.list(params, options)
        retval = [item for item in retval.auto_paging_iter()]
        if not retval:
            return "No remoteservers found."

        markdown_list = object_list_to_markdown_table(
            retval, ["id", "name", "server_type"]
        )
        return f"RemoteServer Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def find_remote_server(
    context: Context,
    id: Annotated[
        int | None, Field(description="Remote Server ID.", default=None)
    ],
) -> str:
    """Show Remote Server

    Args:
        id: Remote Server ID.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if id is None:
            return "Missing required parameter: id"
        params["id"] = id

        retval = files_sdk.remote_server.find(id, params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval, ["id", "name", "server_type"]
        )
        return f"RemoteServer Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


def register_tools(mcp):
    @mcp.tool(name="List_Remote_Server", description="List Remote Servers")
    async def list_remote_server_tool(context: Context) -> str:
        return await list_remote_server(context)

    @mcp.tool(name="Find_Remote_Server", description="Show Remote Server")
    async def find_remote_server_tool(
        context: Context,
        id: Annotated[
            int | None, Field(description="Remote Server ID.", default=None)
        ],
    ) -> str:
        return await find_remote_server(context, id)



from fastmcp import Context
from typing_extensions import Annotated
from pydantic import Field
from files_com_mcp.utils import object_list_to_markdown_table
import files_sdk
import files_sdk.error


async def list_bundle_notification(context: Context) -> str:
    """List Bundle Notifications"""

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}

        retval = files_sdk.bundle_notification.list(params, options)
        retval = [item for item in retval.auto_paging_iter()]
        if not retval:
            return "No bundlenotifications found."

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "bundle_id",
                "notify_user_id",
                "notify_on_registration",
                "notify_on_upload",
            ],
        )
        return f"BundleNotification Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def find_bundle_notification(
    context: Context,
    id: Annotated[
        int | None, Field(description="Bundle Notification ID.", default=None)
    ],
) -> str:
    """Show Bundle (also called Share Link) Notification

    Args:
        id: Bundle Notification ID.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if id is None:
            return "Missing required parameter: id"
        params["id"] = id

        retval = files_sdk.bundle_notification.find(id, params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "bundle_id",
                "notify_user_id",
                "notify_on_registration",
                "notify_on_upload",
            ],
        )
        return f"BundleNotification Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def create_bundle_notification(
    context: Context,
    bundle_id: Annotated[
        int | None, Field(description="Bundle ID to notify on", default=None)
    ],
    notify_user_id: Annotated[
        int | None,
        Field(description="The id of the user to notify.", default=None),
    ],
) -> str:
    """Create Bundle (also called Share Link) Notification

    Args:
        bundle_id: Bundle ID to notify on
        notify_user_id: The id of the user to notify.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if bundle_id is None:
            return "Missing required parameter: bundle_id"
        params["bundle_id"] = bundle_id
        if notify_user_id is not None:
            params["notify_user_id"] = notify_user_id

        # Smart Default(s)
        params["notify_on_registration"] = True

        # Smart Default(s)
        params["notify_on_upload"] = True

        retval = files_sdk.bundle_notification.create(params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "bundle_id",
                "notify_user_id",
                "notify_on_registration",
                "notify_on_upload",
            ],
        )
        return f"BundleNotification Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def update_bundle_notification(
    context: Context,
    id: Annotated[
        int | None, Field(description="Bundle Notification ID.", default=None)
    ],
    notify_on_registration: Annotated[
        bool | None,
        Field(
            description="Triggers bundle notification when a registration action occurs for it.",
            default=None,
        ),
    ],
    notify_on_upload: Annotated[
        bool | None,
        Field(
            description="Triggers bundle notification when a upload action occurs for it.",
            default=None,
        ),
    ],
) -> str:
    """Update Bundle (also called Share Link) Notification

    Args:
        id: Bundle Notification ID.
        notify_on_registration: Triggers bundle notification when a registration action occurs for it.
        notify_on_upload: Triggers bundle notification when a upload action occurs for it.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if id is None:
            return "Missing required parameter: id"
        params["id"] = id
        if notify_on_registration is not None:
            params["notify_on_registration"] = notify_on_registration
        if notify_on_upload is not None:
            params["notify_on_upload"] = notify_on_upload

        retval = files_sdk.bundle_notification.update(id, params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "bundle_id",
                "notify_user_id",
                "notify_on_registration",
                "notify_on_upload",
            ],
        )
        return f"BundleNotification Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


async def delete_bundle_notification(
    context: Context,
    id: Annotated[
        int | None, Field(description="Bundle Notification ID.", default=None)
    ],
) -> str:
    """Delete Bundle (also called Share Link) Notification

    Args:
        id: Bundle Notification ID.
    """

    try:
        options = {
            "api_key": context.request_context.session._files_com_api_key
        }
        params = {}
        if id is None:
            return "Missing required parameter: id"
        params["id"] = id

        retval = files_sdk.bundle_notification.delete(id, params, options)
        retval = [retval]

        markdown_list = object_list_to_markdown_table(
            retval,
            [
                "id",
                "bundle_id",
                "notify_user_id",
                "notify_on_registration",
                "notify_on_upload",
            ],
        )
        return f"BundleNotification Response:\n{markdown_list}"
    except files_sdk.error.NotAuthenticatedError as err:
        return f"Authentication Error: {err}"
    except files_sdk.error.Error as err:
        return f"Files.com Error: {err}"
    except Exception as ex:
        return f"General Exception: {ex}"


def register_tools(mcp):
    @mcp.tool(
        name="List_Bundle_Notification",
        description="List Bundle (also called Share Link) Notifications",
    )
    async def list_bundle_notification_tool(context: Context) -> str:
        return await list_bundle_notification(context)

    @mcp.tool(
        name="Find_Bundle_Notification",
        description="Show Bundle (also called Share Link) Notification",
    )
    async def find_bundle_notification_tool(
        context: Context,
        id: Annotated[
            int | None,
            Field(description="Bundle Notification ID.", default=None),
        ],
    ) -> str:
        return await find_bundle_notification(context, id)

    @mcp.tool(
        name="Create_Bundle_Notification",
        description="Create Bundle (also called Share Link) Notification",
    )
    async def create_bundle_notification_tool(
        context: Context,
        bundle_id: Annotated[
            int | None,
            Field(description="Bundle ID to notify on", default=None),
        ],
        notify_user_id: Annotated[
            int | None,
            Field(description="The id of the user to notify.", default=None),
        ],
    ) -> str:
        return await create_bundle_notification(
            context, bundle_id, notify_user_id
        )

    @mcp.tool(
        name="Update_Bundle_Notification",
        description="Update Bundle (also called Share Link) Notification",
    )
    async def update_bundle_notification_tool(
        context: Context,
        id: Annotated[
            int | None,
            Field(description="Bundle Notification ID.", default=None),
        ],
        notify_on_registration: Annotated[
            bool | None,
            Field(
                description="Triggers bundle notification when a registration action occurs for it.",
                default=None,
            ),
        ],
        notify_on_upload: Annotated[
            bool | None,
            Field(
                description="Triggers bundle notification when a upload action occurs for it.",
                default=None,
            ),
        ],
    ) -> str:
        return await update_bundle_notification(
            context, id, notify_on_registration, notify_on_upload
        )

    @mcp.tool(
        name="Delete_Bundle_Notification",
        description="Delete Bundle (also called Share Link) Notification",
    )
    async def delete_bundle_notification_tool(
        context: Context,
        id: Annotated[
            int | None,
            Field(description="Bundle Notification ID.", default=None),
        ],
    ) -> str:
        return await delete_bundle_notification(context, id)



import requests


async def check_platform_status() -> str:
    """Check Files.com platform status at status.files.com."""
    url = "https://status.files.com/api/v2/status.json"
    try:
        response = requests.get(url)
        if response.status_code == 200:
            return (
                response.json()
                .get("status", {})
                .get("description", "Error processing the status page")
            )
        else:
            return "Error connecting to status page"
    except requests.exceptions.RequestException:
        return "Error connecting to status page"


def register_tools(mcp):
    @mcp.tool(
        name="Check_Platform_Status",
        description="Check Files.com platform status at status.files.com.",
    )
    async def check_platform_status_tool() -> str:
        return await check_platform_status()



import importlib
from files_com_mcp import patches  # noqa: F401
from fastmcp import FastMCP
from fastmcp import settings

# Enable JSON argument parsing for tools. Claude notoriously sends JSON encoded Strings instead
#   of proper JSON list and objects, so this is a workaround to allow the MCP to use those arguments.
settings.tool_attempt_parse_json_args = True

mcp = FastMCP("filescom")


# Dynamically load tools from the tools package
def load_tools():
    # Authored tools
    from files_com_mcp.authored_tools import tool_list as authored_tool_modules

    for module_name in authored_tool_modules:
        module = importlib.import_module(
            f"files_com_mcp.authored_tools.{module_name}"
        )
        if hasattr(module, "register_tools"):
            module.register_tools(mcp)

    # Generated tools
    from files_com_mcp.generated_tools import (
        tool_list as generated_tool_modules,
    )

    for module_name in generated_tool_modules:
        module = importlib.import_module(
            f"files_com_mcp.generated_tools.{module_name}"
        )
        if hasattr(module, "register_tools"):
            module.register_tools(mcp)


def run_stdio():
    """Run the MCP server in stdio mode."""
    load_tools()
    mcp.run(transport="stdio")


def run_server(port: int = 8000):
    """Run the MCP server in HTTP server mode."""
    load_tools()
    mcp.run(transport="sse", host="127.0.0.1", port=port)
